﻿/*
Author: Andy Watt
Revised: 4-22-2009
Website: http://www.wastedpotential.com

This is demo of the AS3 BulkLoader library by Arthur Debert (http://www.stimuli.com.br) 
The latest revision of BulkLoader can be found at http://code.google.com/p/bulk-loader/

This demo implements BulkLoader as a sequential loader, but allows immediate loading
of any item that a user requsts.

Note: BulkLoader doesn't behave the same in the Flash IDE as it does when posted
to a web server. Any testing of BulkLoader should be carried out on an actual web 
server for this reason. Some BulkLoader methods (such as "loadNow") may behave 
differently in various browsers. Test any implementation thoroughly.
*/

package com.wastedpotential {
	import flash.display.MovieClip;
	import flash.display.Bitmap;
	import flash.events.MouseEvent;
	import flash.events.ProgressEvent;
	import flash.events.Event;
	import flash.text.TextField; //needed for dynamic textfields
	import flash.net.URLRequest;
	import flash.net.navigateToURL;
	import br.com.stimuli.loading.BulkLoader;
	import br.com.stimuli.loading.BulkProgressEvent;
	
	public class Main extends MovieClip {
		
		private var bulkLoader:BulkLoader;
		
				
		//===== CONSTRUCTOR =====
		public function Main() {
			//hide the load now buttons:
			loadNow1_mc.visible = false;
			loadNow2_mc.visible = false;
			loadNow3_mc.visible = false;
			loadNow4_mc.visible = false;
			
			//create bulk loader:
			bulkLoader = new BulkLoader("mainpageloader");
			
			//add items to bulkloader:
			//id = the name used to reference this item later 
			//priority = the order to load this item. Higher numbers load first
			bulkLoader.add("images/image1.jpg", {id:"item1", priority:100});			
			bulkLoader.add("images/image2.jpg", {id:"item2", priority:90});			
			bulkLoader.add("images/image3.jpg", {id:"item3", priority:80});			
			bulkLoader.add("images/image4.jpg", {id:"item4", priority:70});			
			
			//set up progress listeners for each individual item:
			bulkLoader.get("item1").addEventListener(ProgressEvent.PROGRESS, onItemProgress1);
			bulkLoader.get("item2").addEventListener(ProgressEvent.PROGRESS, onItemProgress2);
			bulkLoader.get("item3").addEventListener(ProgressEvent.PROGRESS, onItemProgress3);
			bulkLoader.get("item4").addEventListener(ProgressEvent.PROGRESS, onItemProgress4);
			
			//set up complete listeners for each individual item:
			bulkLoader.get("item1").addEventListener(Event.COMPLETE, onItemComplete1);
			bulkLoader.get("item2").addEventListener(Event.COMPLETE, onItemComplete2);
			bulkLoader.get("item3").addEventListener(Event.COMPLETE, onItemComplete3);
			bulkLoader.get("item4").addEventListener(Event.COMPLETE, onItemComplete4);
			
			//set up main loading button:
			startAll_mc.addEventListener(MouseEvent.CLICK, startBulkLoader);			
			
			//add listeners for total loading progress:
			//bulkLoader.addEventListener(BulkLoader.COMPLETE, onCompleteHandler);
			bulkLoader.addEventListener(BulkLoader.PROGRESS, onTotalProgress);	
			
			//set up link button:
			linkButton_mc.addEventListener(MouseEvent.CLICK, onLinkClick);
		}
				
		//===== total bulk loading progress handler: =====
		private function onTotalProgress(e:BulkProgressEvent):void {
			//this will not work because it won't show the data until the last item starts:
			//percentTextAll.text = Math.floor(1000*e.bytesLoaded/bytesTotal)/10 + "%";  
			
			//"weightPercent" gives the most accurate total loading progress:
			percentTextAll.text = Math.floor(1000*e.weightPercent)/10 + "%";  
			//if loaded items are not similar in size, you will need to add a "weight" parameter to each item in the bulkloader for an accurate percentage
			
			//a low-overhead way to do it is with "ratioLoaded":
			//allPercentText.text = Math.floor(1000*e.ratioLoaded)/10 + "%"; 
			//this works best for large numbers of small files
		}
		
		//===== starts bulkloader and activates the individual load buttons: =====
		private function startBulkLoader(e:MouseEvent):void {
			bulkLoader.start(1); //parameter = the number of items that you wish to load simultaneously (sequential loader=1)
			
			//set up individual buttons ONLY AFTER BULKLOADER IS STARTED:
			loadNow1_mc.addEventListener(MouseEvent.CLICK, loadItem1);
			loadNow2_mc.addEventListener(MouseEvent.CLICK, loadItem2);
			loadNow3_mc.addEventListener(MouseEvent.CLICK, loadItem3);
			loadNow4_mc.addEventListener(MouseEvent.CLICK, loadItem4);
			
			//show the load now buttons:
			loadNow1_mc.visible = true;
			loadNow2_mc.visible = true;
			loadNow3_mc.visible = true;
			loadNow4_mc.visible = true;			
		}
		
		//===== link button handler: =====
		private function onLinkClick(e:MouseEvent):void {
			navigateToURL(new URLRequest("http://www.wastedpotential.com"));
		}
		
		
		/////////////////////// LOAD NOW BUTTON HANDLERS: ////////////////////////
		
		//===== item 1 load now button click handler: =====
		private function loadItem1(e:MouseEvent):void {
			bulkLoader.loadNow("item1");			
		}		
		
		//===== item 2 load now button click handler: =====
		private function loadItem2(e:MouseEvent):void {
			bulkLoader.loadNow("item2");			
		}		
		
		//===== item 3 load now button click handler: =====
		private function loadItem3(e:MouseEvent):void {
			bulkLoader.loadNow("item3");			
		}		
		
		//===== item 4 load now button click handler: =====
		private function loadItem4(e:MouseEvent):void {
			bulkLoader.loadNow("item4");			
		}		
		
		
		/////////////////////// ITEM PROGRESS HANDLERS: ////////////////////////
		
		//===== item 1 progress handler: =====
		private function onItemProgress1(e:ProgressEvent):void {
			percentText1.text = Math.floor(100*e.bytesLoaded/e.bytesTotal) + "%";
		}		
		
		//===== item 2 progress handler: =====
		private function onItemProgress2(e:ProgressEvent):void {
			percentText2.text = Math.floor(100*e.bytesLoaded/e.bytesTotal) + "%";
		}		
		
		//===== item 3 progress handler: =====
		private function onItemProgress3(e:ProgressEvent):void {
			percentText3.text = Math.floor(100*e.bytesLoaded/e.bytesTotal) + "%";
		}		
		
		//===== item 4 progress handler: =====
		private function onItemProgress4(e:ProgressEvent):void {
			percentText4.text = Math.floor(100*e.bytesLoaded/e.bytesTotal) + "%";
		}		
		
		
		/////////////////////// ITEM COMPLETE HANDLERS: ////////////////////////
		
		//===== item 1 complete handler: =====
		private function onItemComplete1(e:Event):void {
			var item:Bitmap = bulkLoader.getBitmap("item1");
			item.scaleX = getScaleX(item, bitmapHolder1_mc);
			item.scaleY = getScaleY(item, bitmapHolder1_mc);
			bitmapHolder1_mc.addChild(item);
		}		
		
		//===== item 2 complete handler: =====
		private function onItemComplete2(e:Event):void {
			var item:Bitmap = bulkLoader.getBitmap("item2");
			item.scaleX = getScaleX(item, bitmapHolder2_mc);
			item.scaleY = getScaleY(item, bitmapHolder2_mc);
			bitmapHolder2_mc.addChild(item);
		}		
		
		//===== item 3 complete handler: =====
		private function onItemComplete3(e:Event):void {
			var item:Bitmap = bulkLoader.getBitmap("item3");
			item.scaleX = getScaleX(item, bitmapHolder3_mc);
			item.scaleY = getScaleY(item, bitmapHolder3_mc);
			bitmapHolder3_mc.addChild(item);
		}		
		
		//===== item 4 complete handler: =====
		private function onItemComplete4(e:Event):void {
			var item:Bitmap = bulkLoader.getBitmap("item4");
			item.scaleX = getScaleX(item, bitmapHolder4_mc);
			item.scaleY = getScaleY(item, bitmapHolder4_mc);
			bitmapHolder4_mc.addChild(item);
		}		
		
		//===== returns an X scale factor for mapping an image onto a targetmovieclip: =====
		private function getScaleX(image:Bitmap, targetClip:MovieClip):Number {
			return targetClip.width/image.width;
		}
		
		//===== returns a Y scale factor for mapping an image onto a targetmovieclip: =====
		private function getScaleY(image:Bitmap, targetClip:MovieClip):Number {
			return targetClip.height/image.height;
		}
		
	} //end class
} //end package